test: Replace _TEST_CASE_ with _TEST_SUITE_ in /components/autofill.

Googletest is (at last) converging with industry-standard terminology
[1]. We previously called test suites "test cases", which was rather
confusing for folks coming from any other testing framework.

Chrome now has a googltest version that supports _TEST_SUITE_ macros
instead of _TEST_CASE_, so this CL cleans up some of the outdated usage.

[1] https://github.com/google/googletest/blob/master/googletest/docs/primer.md#beware-of-the-nomenclature

This CL was uploaded by git cl split.

R=rogerm@chromium.org

Bug: 925652
Change-Id: I70982ea2118322ffd5ea133a6790d9726069ce7b
Reviewed-on: https://chromium-review.googlesource.com/c/1438314
Reviewed-by: Roger McFarlane <rogerm@chromium.org>
Commit-Queue: Roger McFarlane <rogerm@chromium.org>
Cr-Commit-Position: refs/heads/master@{#631373}
diff --git a/components/autofill/core/browser/address_i18n_unittest.cc b/components/autofill/core/browser/address_i18n_unittest.cc
index 2647d888..0f96565 100644
--- a/components/autofill/core/browser/address_i18n_unittest.cc
+++ b/components/autofill/core/browser/address_i18n_unittest.cc
@@ -55,7 +55,7 @@
   EXPECT_EQ(test_data.server_field, server_field);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AddressI18nTest,
     FieldTypeMirrorConversionsTest,
     testing::Values(
@@ -108,17 +108,17 @@
   EXPECT_EQ(test_data.expected_address_field, actual_address_field);
 }
 
-INSTANTIATE_TEST_CASE_P(AddressI18nTest,
-                        FieldTypeUnidirectionalConversionsTest,
-                        testing::Values(
-                            FieldTypeUnidirectionalConversionsTestCase{
-                                ADDRESS_BILLING_LINE1, STREET_ADDRESS},
-                            FieldTypeUnidirectionalConversionsTestCase{
-                                ADDRESS_BILLING_LINE2, STREET_ADDRESS},
-                            FieldTypeUnidirectionalConversionsTestCase{
-                                ADDRESS_HOME_LINE1, STREET_ADDRESS},
-                            FieldTypeUnidirectionalConversionsTestCase{
-                                ADDRESS_HOME_LINE2, STREET_ADDRESS}));
+INSTANTIATE_TEST_SUITE_P(AddressI18nTest,
+                         FieldTypeUnidirectionalConversionsTest,
+                         testing::Values(
+                             FieldTypeUnidirectionalConversionsTestCase{
+                                 ADDRESS_BILLING_LINE1, STREET_ADDRESS},
+                             FieldTypeUnidirectionalConversionsTestCase{
+                                 ADDRESS_BILLING_LINE2, STREET_ADDRESS},
+                             FieldTypeUnidirectionalConversionsTestCase{
+                                 ADDRESS_HOME_LINE1, STREET_ADDRESS},
+                             FieldTypeUnidirectionalConversionsTestCase{
+                                 ADDRESS_HOME_LINE2, STREET_ADDRESS}));
 
 TEST(AddressI18nTest, UnconvertableServerFields) {
   EXPECT_FALSE(FieldForType(PHONE_HOME_NUMBER, nullptr));
diff --git a/components/autofill/core/browser/autofill_data_model_unittest.cc b/components/autofill/core/browser/autofill_data_model_unittest.cc
index 2f0c40f..f719d9b 100644
--- a/components/autofill/core/browser/autofill_data_model_unittest.cc
+++ b/components/autofill/core/browser/autofill_data_model_unittest.cc
@@ -138,7 +138,7 @@
             model_b.HasGreaterFrecencyThan(&model_a, now));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillDataModelTest,
     HasGreaterFrecencyThanTest,
     testing::Values(
diff --git a/components/autofill/core/browser/autofill_data_util_unittest.cc b/components/autofill/core/browser/autofill_data_util_unittest.cc
index d2de515..57c7748b 100644
--- a/components/autofill/core/browser/autofill_data_util_unittest.cc
+++ b/components/autofill/core/browser/autofill_data_util_unittest.cc
@@ -25,7 +25,7 @@
       << "Failed for: " << test_case.full_name;
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillDataUtilTest,
     IsCJKNameTest,
     testing::Values(
@@ -73,7 +73,7 @@
   EXPECT_EQ(base::UTF8ToUTF16(test_case.family_name), name_parts.family);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillDataUtil,
     SplitNameTest,
     testing::Values(
@@ -150,7 +150,7 @@
   EXPECT_EQ(base::UTF8ToUTF16(test_case.full_name), joined);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillDataUtil,
     JoinNamePartsTest,
     testing::Values(
@@ -213,7 +213,7 @@
             IsValidCountryCode(test_case.country_code));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillDataUtil,
     ValidCountryCodeTest,
     testing::Values(
diff --git a/components/autofill/core/browser/autofill_download_manager_unittest.cc b/components/autofill/core/browser/autofill_download_manager_unittest.cc
index c6ae22d..5f2d642a 100644
--- a/components/autofill/core/browser/autofill_download_manager_unittest.cc
+++ b/components/autofill/core/browser/autofill_download_manager_unittest.cc
@@ -1188,11 +1188,11 @@
 
 // Note that we omit DEFAULT_URL from the test params. We don't actually want
 // the tests to hit the production server.
-INSTANTIATE_TEST_CASE_P(All,
-                        AutofillServerCommunicationTest,
-                        ::testing::Values(DISABLED,
-                                          FINCHED_URL,
-                                          COMMAND_LINE_URL));
+INSTANTIATE_TEST_SUITE_P(All,
+                         AutofillServerCommunicationTest,
+                         ::testing::Values(DISABLED,
+                                           FINCHED_URL,
+                                           COMMAND_LINE_URL));
 
 using AutofillQueryTest = AutofillServerCommunicationTest;
 
@@ -1468,9 +1468,9 @@
 // Note that we omit DEFAULT_URL from the test params. We don't actually want
 // the tests to hit the production server. We also excluded DISABLED, since
 // these tests exercise "enabled" functionality.
-INSTANTIATE_TEST_CASE_P(All,
-                        AutofillQueryTest,
-                        ::testing::Values(FINCHED_URL, COMMAND_LINE_URL));
+INSTANTIATE_TEST_SUITE_P(All,
+                         AutofillQueryTest,
+                         ::testing::Values(FINCHED_URL, COMMAND_LINE_URL));
 
 using AutofillUploadTest = AutofillServerCommunicationTest;
 
@@ -1779,8 +1779,8 @@
 // Note that we omit DEFAULT_URL from the test params. We don't actually want
 // the tests to hit the production server. We also excluded DISABLED, since
 // these tests exercise "enabled" functionality.
-INSTANTIATE_TEST_CASE_P(All,
-                        AutofillUploadTest,
-                        ::testing::Values(FINCHED_URL, COMMAND_LINE_URL));
+INSTANTIATE_TEST_SUITE_P(All,
+                         AutofillUploadTest,
+                         ::testing::Values(FINCHED_URL, COMMAND_LINE_URL));
 
 }  // namespace autofill
diff --git a/components/autofill/core/browser/autofill_manager_unittest.cc b/components/autofill/core/browser/autofill_manager_unittest.cc
index d66e4e83..8cf4979 100644
--- a/components/autofill/core/browser/autofill_manager_unittest.cc
+++ b/components/autofill/core/browser/autofill_manager_unittest.cc
@@ -4612,7 +4612,7 @@
   }
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillManagerTest,
     ProfileMatchingTypesTest,
     testing::Combine(
@@ -6520,6 +6520,6 @@
   CheckNoSuggestionsAvailableOnFieldFocus();
 }
 
-INSTANTIATE_TEST_CASE_P(All, OnFocusOnFormFieldTest, testing::Bool());
+INSTANTIATE_TEST_SUITE_P(All, OnFocusOnFormFieldTest, testing::Bool());
 
 }  // namespace autofill
diff --git a/components/autofill/core/browser/autofill_merge_unittest.cc b/components/autofill/core/browser/autofill_merge_unittest.cc
index caf3483..bd1bbb31 100644
--- a/components/autofill/core/browser/autofill_merge_unittest.cc
+++ b/components/autofill/core/browser/autofill_merge_unittest.cc
@@ -304,6 +304,8 @@
                        kIsExpectedToPass);
 }
 
-INSTANTIATE_TEST_CASE_P(, AutofillMergeTest, testing::ValuesIn(GetTestFiles()));
+INSTANTIATE_TEST_SUITE_P(,
+                         AutofillMergeTest,
+                         testing::ValuesIn(GetTestFiles()));
 
 }  // namespace autofill
diff --git a/components/autofill/core/browser/autofill_metrics_unittest.cc b/components/autofill/core/browser/autofill_metrics_unittest.cc
index 8755580..e158a7c 100644
--- a/components/autofill/core/browser/autofill_metrics_unittest.cc
+++ b/components/autofill/core/browser/autofill_metrics_unittest.cc
@@ -470,9 +470,9 @@
   const std::string credit_card_form_events_frame_histogram_;
 };
 
-INSTANTIATE_TEST_CASE_P(AutofillMetricsTest,
-                        AutofillMetricsIFrameTest,
-                        testing::Bool());
+INSTANTIATE_TEST_SUITE_P(AutofillMetricsTest,
+                         AutofillMetricsIFrameTest,
+                         testing::Bool());
 
 // Test parameter indicates if the metrics are being logged for a form in an
 // iframe or the main frame. True means the form is in the main frame.
@@ -494,9 +494,9 @@
   base::test::ScopedFeatureList scoped_feature_list_;
 };
 
-INSTANTIATE_TEST_CASE_P(AutofillMetricsTest,
-                        AutofillMetricsCompanyTest,
-                        testing::Bool());
+INSTANTIATE_TEST_SUITE_P(AutofillMetricsTest,
+                         AutofillMetricsCompanyTest,
+                         testing::Bool());
 
 // Test that we log quality metrics appropriately.
 TEST_F(AutofillMetricsTest, QualityMetrics) {
@@ -1739,7 +1739,7 @@
   }
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillMetricsTest,
     QualityMetricsTest,
     testing::Values(QualityMetricsTestCase{NO_SERVER_DATA, EMPTY_TYPE},
diff --git a/components/autofill/core/browser/contact_info_unittest.cc b/components/autofill/core/browser/contact_info_unittest.cc
index d07dfa0..3f2502fa 100644
--- a/components/autofill/core/browser/contact_info_unittest.cc
+++ b/components/autofill/core/browser/contact_info_unittest.cc
@@ -46,7 +46,7 @@
             name.GetInfo(AutofillType(NAME_FULL), "en-US"));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     ContactInfoTest,
     SetFullNameTest,
     testing::Values(
@@ -215,7 +215,7 @@
               starting_profile.ParsedNamesAreEqual(additional_profile));
   }
 
-  INSTANTIATE_TEST_CASE_P(
+  INSTANTIATE_TEST_SUITE_P(
       ContactInfoTest,
       ParsedNamesAreEqualTest,
       testing::Values(
@@ -308,7 +308,7 @@
               existing_name.GetRawInfo(NAME_FULL));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     ContactInfoTest,
     OverwriteNameTest,
     testing::Values(
@@ -387,7 +387,7 @@
     EXPECT_EQ(test_case.expected_result, name.NamePartsAreEmpty());
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     ContactInfoTest,
     NamePartsAreEmptyTest,
     testing::Values(NamePartsAreEmptyTestCase{"", "", "", "", true},
diff --git a/components/autofill/core/browser/credit_card_field_unittest.cc b/components/autofill/core/browser/credit_card_field_unittest.cc
index f701a39..35ee3dba 100644
--- a/components/autofill/core/browser/credit_card_field_unittest.cc
+++ b/components/autofill/core/browser/credit_card_field_unittest.cc
@@ -375,7 +375,7 @@
             field_candidates_map_[ASCIIToUTF16("exp3")].BestHeuristicType());
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardFieldTest,
     ParseExpFieldTest,
     testing::Values(
diff --git a/components/autofill/core/browser/field_filler_unittest.cc b/components/autofill/core/browser/field_filler_unittest.cc
index 3bed68d2..77dd9cf4 100644
--- a/components/autofill/core/browser/field_filler_unittest.cc
+++ b/components/autofill/core/browser/field_filler_unittest.cc
@@ -480,7 +480,7 @@
   EXPECT_EQ(ASCIIToUTF16(test_case.expected_value), field.value);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     PhoneNumberTest,
     testing::Values(
@@ -530,7 +530,7 @@
   EXPECT_EQ(ASCIIToUTF16(test_case.expected_value), field.value);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     ExpirationYearTest,
     testing::Values(
@@ -594,7 +594,7 @@
   EXPECT_EQ(response, test_case.expected_response);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     ExpirationDateTest,
     testing::Values(
@@ -784,7 +784,7 @@
   }
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     AutofillSelectWithStatesTest,
     testing::Values(
@@ -872,7 +872,7 @@
                              test_case.select_values.size());
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     AutofillSelectWithExpirationMonthTest,
     testing::Values(
@@ -1358,7 +1358,7 @@
   EXPECT_EQ(ASCIIToUTF16(test_case.expected_value), field.value);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillFieldFillerTest,
     AutofillStateTextTest,
     testing::Values(
diff --git a/components/autofill/core/browser/legal_message_line_unittest.cc b/components/autofill/core/browser/legal_message_line_unittest.cc
index 20d7a5d..c913503 100644
--- a/components/autofill/core/browser/legal_message_line_unittest.cc
+++ b/components/autofill/core/browser/legal_message_line_unittest.cc
@@ -116,7 +116,7 @@
   EXPECT_EQ(GetParam().expected_lines, actual_lines);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     TestCases,
     LegalMessageLineTest,
     testing::Values(
diff --git a/components/autofill/core/browser/personal_data_manager_unittest.cc b/components/autofill/core/browser/personal_data_manager_unittest.cc
index 9955875..ecdd4ae 100644
--- a/components/autofill/core/browser/personal_data_manager_unittest.cc
+++ b/components/autofill/core/browser/personal_data_manager_unittest.cc
@@ -3840,7 +3840,7 @@
   ResetProfiles();
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     PersonalDataManagerTest,
     SaveImportedProfileTest,
     testing::Values(
diff --git a/components/autofill/core/browser/phone_number_i18n_unittest.cc b/components/autofill/core/browser/phone_number_i18n_unittest.cc
index 5410397..16269c3 100644
--- a/components/autofill/core/browser/phone_number_i18n_unittest.cc
+++ b/components/autofill/core/browser/phone_number_i18n_unittest.cc
@@ -90,7 +90,7 @@
   EXPECT_EQ(test_case.deduced_region, deduced_region);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     PhoneNumberI18NTest,
     ParseNumberTest,
     testing::Values(
@@ -314,7 +314,7 @@
                 profile, GetParam().locale)));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     GetFormattedPhoneNumberForDisplay,
     GetFormattedPhoneNumberForDisplayTest,
     testing::Values(
@@ -421,7 +421,7 @@
         // This number is not a valid US number, we won't try to format.
         PhoneNumberFormatCase("55 5342 8400", "US", "5553428400")));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     GetFormattedPhoneNumberForDisplay_EdgeCases,
     GetFormattedPhoneNumberForDisplayTest,
     testing::Values(
diff --git a/components/autofill/core/browser/randomized_encoder_unittest.cc b/components/autofill/core/browser/randomized_encoder_unittest.cc
index d034c86..9819106 100644
--- a/components/autofill/core/browser/randomized_encoder_unittest.cc
+++ b/components/autofill/core/browser/randomized_encoder_unittest.cc
@@ -160,9 +160,9 @@
   EXPECT_EQ(expected_result, actual_result);
 }
 
-INSTANTIATE_TEST_CASE_P(All,
-                        RandomizedEncoderTest,
-                        ::testing::ValuesIn(kEncodeParams));
+INSTANTIATE_TEST_SUITE_P(All,
+                         RandomizedEncoderTest,
+                         ::testing::ValuesIn(kEncodeParams));
 
 namespace {
 
@@ -321,6 +321,6 @@
   }
 }
 
-INSTANTIATE_TEST_CASE_P(All,
-                        RandomizedDecoderTest,
-                        ::testing::ValuesIn(kDecodeParams));
+INSTANTIATE_TEST_SUITE_P(All,
+                         RandomizedDecoderTest,
+                         ::testing::ValuesIn(kDecodeParams));
diff --git a/components/autofill/core/browser/ui/card_unmask_prompt_controller_impl_unittest.cc b/components/autofill/core/browser/ui/card_unmask_prompt_controller_impl_unittest.cc
index 5295546..9012160a 100644
--- a/components/autofill/core/browser/ui/card_unmask_prompt_controller_impl_unittest.cc
+++ b/components/autofill/core/browser/ui/card_unmask_prompt_controller_impl_unittest.cc
@@ -500,12 +500,12 @@
             delegate_->response().cvc);
 }
 
-INSTANTIATE_TEST_CASE_P(CardUnmaskPromptControllerImplTest,
-                        CvcInputValidationTest,
-                        testing::Values(CvcCase{"123", true, "123"},
-                                        CvcCase{"123 ", true, "123"},
-                                        CvcCase{" 1234 ", false},
-                                        CvcCase{"IOU", false}));
+INSTANTIATE_TEST_SUITE_P(CardUnmaskPromptControllerImplTest,
+                         CvcInputValidationTest,
+                         testing::Values(CvcCase{"123", true, "123"},
+                                         CvcCase{"123 ", true, "123"},
+                                         CvcCase{" 1234 ", false},
+                                         CvcCase{"IOU", false}));
 
 class CvcInputAmexValidationTest
     : public CardUnmaskPromptControllerImplGenericTest,
@@ -541,14 +541,14 @@
             delegate_->response().cvc);
 }
 
-INSTANTIATE_TEST_CASE_P(CardUnmaskPromptControllerImplTest,
-                        CvcInputAmexValidationTest,
-                        testing::Values(CvcCase{"123", false},
-                                        CvcCase{"123 ", false},
-                                        CvcCase{"1234", true, "1234"},
-                                        CvcCase{"\t1234 ", true, "1234"},
-                                        CvcCase{" 1234", true, "1234"},
-                                        CvcCase{"IOU$", false}));
+INSTANTIATE_TEST_SUITE_P(CardUnmaskPromptControllerImplTest,
+                         CvcInputAmexValidationTest,
+                         testing::Values(CvcCase{"123", false},
+                                         CvcCase{"123 ", false},
+                                         CvcCase{"1234", true, "1234"},
+                                         CvcCase{"\t1234 ", true, "1234"},
+                                         CvcCase{" 1234", true, "1234"},
+                                         CvcCase{"IOU$", false}));
 
 struct ExpirationDateTestCase {
   const char* input_month;
@@ -584,7 +584,7 @@
                                 ASCIIToUTF16(exp_case.input_year)));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CardUnmaskPromptControllerImplTest,
     ExpirationDateValidationTest,
     testing::Values(ExpirationDateTestCase{"01", "2040", true},
diff --git a/components/autofill/core/browser/validation_unittest.cc b/components/autofill/core/browser/validation_unittest.cc
index b9a9808..2604226 100644
--- a/components/autofill/core/browser/validation_unittest.cc
+++ b/components/autofill/core/browser/validation_unittest.cc
@@ -188,7 +188,7 @@
   }
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardExpDate,
     AutofillTypeValidationTest,
     testing::Values(
@@ -231,7 +231,7 @@
                        false,
                        IDS_PAYMENTS_VALIDATION_INVALID_CREDIT_CARD_EXPIRED)));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardMonth,
     AutofillTypeValidationTest,
     testing::Values(
@@ -254,7 +254,7 @@
             false,
             IDS_PAYMENTS_VALIDATION_INVALID_CREDIT_CARD_EXPIRATION_MONTH)));
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardYear,
     AutofillTypeValidationTest,
     testing::Values(
@@ -351,7 +351,7 @@
     "amex",       "discover", "diners",   "elo",  "jcb",
     "mastercard", "mir",      "unionpay", "visa"};
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardNumber,
     AutofillCCNumberValidationTest,
     testing::Values(
@@ -433,7 +433,7 @@
             GetCvcLengthForCardType(GetParam().card_type));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardCvcLength,
     AutofillGetCvcLengthForCardType,
     testing::Values(
@@ -465,33 +465,33 @@
       IsUPIVirtualPaymentAddress(ASCIIToUTF16("user@" + GetParam() + ".com")));
 }
 
-INSTANTIATE_TEST_CASE_P(UPIVirtualPaymentAddress,
-                        AutofillIsUPIVirtualPaymentAddress,
-                        testing::Values("upi",
-                                        "allbank",
-                                        "andb",
-                                        "axisbank",
-                                        "barodampay",
-                                        "mahb",
-                                        "cnrb",
-                                        "csbpay",
-                                        "dcb",
-                                        "federal",
-                                        "hdfcbank",
-                                        "pockets",
-                                        "icici",
-                                        "idfcbank",
-                                        "indus",
-                                        "kbl",
-                                        "kaypay",
-                                        "pnb",
-                                        "sib",
-                                        "sbi",
-                                        "tjsb",
-                                        "uco",
-                                        "unionbank",
-                                        "united",
-                                        "vijb",
-                                        "ybl"));
+INSTANTIATE_TEST_SUITE_P(UPIVirtualPaymentAddress,
+                         AutofillIsUPIVirtualPaymentAddress,
+                         testing::Values("upi",
+                                         "allbank",
+                                         "andb",
+                                         "axisbank",
+                                         "barodampay",
+                                         "mahb",
+                                         "cnrb",
+                                         "csbpay",
+                                         "dcb",
+                                         "federal",
+                                         "hdfcbank",
+                                         "pockets",
+                                         "icici",
+                                         "idfcbank",
+                                         "indus",
+                                         "kbl",
+                                         "kaypay",
+                                         "pnb",
+                                         "sib",
+                                         "sbi",
+                                         "tjsb",
+                                         "uco",
+                                         "unionbank",
+                                         "united",
+                                         "vijb",
+                                         "ybl"));
 
 }  // namespace autofill
diff --git a/components/autofill/core/browser/webdata/autofill_profile_syncable_service_unittest.cc b/components/autofill/core/browser/webdata/autofill_profile_syncable_service_unittest.cc
index b4dc3f5..1b605e94 100644
--- a/components/autofill/core/browser/webdata/autofill_profile_syncable_service_unittest.cc
+++ b/components/autofill/core/browser/webdata/autofill_profile_syncable_service_unittest.cc
@@ -1557,7 +1557,7 @@
   autofill_syncable_service_.StopSyncing(syncer::AUTOFILL_PROFILE);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillProfileSyncableServiceTest,
     SyncUpdatesUsageStatsTest,
     testing::Values(
diff --git a/components/autofill/core/browser/webdata/autofill_table_unittest.cc b/components/autofill/core/browser/webdata/autofill_table_unittest.cc
index 14d9f4e..13d04b9 100644
--- a/components/autofill/core/browser/webdata/autofill_table_unittest.cc
+++ b/components/autofill/core/browser/webdata/autofill_table_unittest.cc
@@ -2831,7 +2831,7 @@
   table_->RemoveFormElementsAddedBetween(t1, Time(), &changes);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillTableTest,
     GetFormValuesTest,
     testing::Values(GetFormValuesTestCase{{"user.test", "test_user"},
@@ -2979,10 +2979,10 @@
   EXPECT_FALSE(table_->GetAllSyncMetadata(model_type, &metadata_batch));
 }
 
-INSTANTIATE_TEST_CASE_P(AutofillTableTest,
-                        AutofillTableTestPerModelType,
-                        testing::Values(syncer::AUTOFILL,
-                                        syncer::AUTOFILL_PROFILE));
+INSTANTIATE_TEST_SUITE_P(AutofillTableTest,
+                         AutofillTableTestPerModelType,
+                         testing::Values(syncer::AUTOFILL,
+                                         syncer::AUTOFILL_PROFILE));
 
 TEST_F(AutofillTableTest, RemoveOrphanAutofillTableRows) {
   // Populate the different tables.
diff --git a/components/autofill/core/common/autofill_regexes_unittest.cc b/components/autofill/core/common/autofill_regexes_unittest.cc
index 4b0820d5..4201bce 100644
--- a/components/autofill/core/common/autofill_regexes_unittest.cc
+++ b/components/autofill/core/common/autofill_regexes_unittest.cc
@@ -32,23 +32,23 @@
                                ASCIIToUTF16(test_case.pattern)));
   }
 
-  INSTANTIATE_TEST_CASE_P(AutofillRegexes,
-                          PositiveSampleTest,
-                          testing::Values(
-                              // Empty pattern
-                              InputPatternTestCase{"", ""},
-                              InputPatternTestCase{
-                                  "Look, ma' -- a non-empty string!", ""},
-                              // Substring
-                              InputPatternTestCase{"string", "tri"},
-                              // Substring at beginning
-                              InputPatternTestCase{"string", "str"},
-                              InputPatternTestCase{"string", "^str"},
-                              // Substring at end
-                              InputPatternTestCase{"string", "ring"},
-                              InputPatternTestCase{"string", "ring$"},
-                              // Case-insensitive
-                              InputPatternTestCase{"StRiNg", "string"}));
+  INSTANTIATE_TEST_SUITE_P(AutofillRegexes,
+                           PositiveSampleTest,
+                           testing::Values(
+                               // Empty pattern
+                               InputPatternTestCase{"", ""},
+                               InputPatternTestCase{
+                                   "Look, ma' -- a non-empty string!", ""},
+                               // Substring
+                               InputPatternTestCase{"string", "tri"},
+                               // Substring at beginning
+                               InputPatternTestCase{"string", "str"},
+                               InputPatternTestCase{"string", "^str"},
+                               // Substring at end
+                               InputPatternTestCase{"string", "ring"},
+                               InputPatternTestCase{"string", "ring$"},
+                               // Case-insensitive
+                               InputPatternTestCase{"StRiNg", "string"}));
 
   class NegativeSampleTest
       : public testing::TestWithParam<InputPatternTestCase> {};
@@ -61,20 +61,20 @@
                                 ASCIIToUTF16(test_case.pattern)));
 }
 
-INSTANTIATE_TEST_CASE_P(AutofillRegexes,
-                        NegativeSampleTest,
-                        testing::Values(
-                            // Empty string
-                            InputPatternTestCase{
-                                "", "Look, ma' -- a non-empty pattern!"},
-                            // Substring
-                            InputPatternTestCase{"string", "trn"},
-                            // Substring at beginning
-                            InputPatternTestCase{"string", " str"},
-                            InputPatternTestCase{"string", "^tri"},
-                            // Substring at end
-                            InputPatternTestCase{"string", "ring "},
-                            InputPatternTestCase{"string", "rin$"}));
+INSTANTIATE_TEST_SUITE_P(AutofillRegexes,
+                         NegativeSampleTest,
+                         testing::Values(
+                             // Empty string
+                             InputPatternTestCase{
+                                 "", "Look, ma' -- a non-empty pattern!"},
+                             // Substring
+                             InputPatternTestCase{"string", "trn"},
+                             // Substring at beginning
+                             InputPatternTestCase{"string", " str"},
+                             InputPatternTestCase{"string", "^tri"},
+                             // Substring at end
+                             InputPatternTestCase{"string", "ring "},
+                             InputPatternTestCase{"string", "rin$"}));
 
 struct InputTestCase {
   const char* const input;
@@ -90,7 +90,7 @@
     EXPECT_TRUE(MatchesPattern(ASCIIToUTF16(test_case.input), pattern));
   }
 
-  INSTANTIATE_TEST_CASE_P(
+  INSTANTIATE_TEST_SUITE_P(
       AutofillRegexes,
       ExpirationDate2DigitYearPositive,
       testing::Values(InputTestCase{"mm / yy"},
@@ -124,7 +124,7 @@
     EXPECT_FALSE(MatchesPattern(ASCIIToUTF16(test_case.input), pattern));
   }
 
-  INSTANTIATE_TEST_CASE_P(
+  INSTANTIATE_TEST_SUITE_P(
       AutofillRegexes,
       ExpirationDate2DigitYearNegative,
       testing::Values(InputTestCase{""},
@@ -164,30 +164,30 @@
     EXPECT_TRUE(MatchesPattern(ASCIIToUTF16(test_case.input), pattern));
   }
 
-  INSTANTIATE_TEST_CASE_P(AutofillRegexes,
-                          ExpirationDate4DigitYearPositive,
-                          testing::Values(
-                              // Simple four year cases
-                              InputTestCase{"mm / yyyy"},
-                              InputTestCase{"mm/ yyyy"},
-                              InputTestCase{"mm /yyyy"},
-                              InputTestCase{"mm/yyyy"},
-                              InputTestCase{"mm - yyyy"},
-                              InputTestCase{"mm- yyyy"},
-                              InputTestCase{"mm -yyyy"},
-                              InputTestCase{"mm-yyyy"},
-                              InputTestCase{"mmyyyy"},
-                              // Complex four year cases
-                              InputTestCase{"Expiration Date (MM / YYYY)"},
-                              InputTestCase{"Expiration Date (MM/YYYY)"},
-                              InputTestCase{"Expiration Date (MM - YYYY)"},
-                              InputTestCase{"Expiration Date (MM-YYYY)"},
-                              InputTestCase{"Expiration Date MM / YYYY"},
-                              InputTestCase{"Expiration Date MM/YYYY"},
-                              InputTestCase{"Expiration Date MM - YYYY"},
-                              InputTestCase{"Expiration Date MM-YYYY"},
-                              InputTestCase{"expiration date yyyy"},
-                              InputTestCase{"Exp Date     (MM / YYYY)"}));
+  INSTANTIATE_TEST_SUITE_P(AutofillRegexes,
+                           ExpirationDate4DigitYearPositive,
+                           testing::Values(
+                               // Simple four year cases
+                               InputTestCase{"mm / yyyy"},
+                               InputTestCase{"mm/ yyyy"},
+                               InputTestCase{"mm /yyyy"},
+                               InputTestCase{"mm/yyyy"},
+                               InputTestCase{"mm - yyyy"},
+                               InputTestCase{"mm- yyyy"},
+                               InputTestCase{"mm -yyyy"},
+                               InputTestCase{"mm-yyyy"},
+                               InputTestCase{"mmyyyy"},
+                               // Complex four year cases
+                               InputTestCase{"Expiration Date (MM / YYYY)"},
+                               InputTestCase{"Expiration Date (MM/YYYY)"},
+                               InputTestCase{"Expiration Date (MM - YYYY)"},
+                               InputTestCase{"Expiration Date (MM-YYYY)"},
+                               InputTestCase{"Expiration Date MM / YYYY"},
+                               InputTestCase{"Expiration Date MM/YYYY"},
+                               InputTestCase{"Expiration Date MM - YYYY"},
+                               InputTestCase{"Expiration Date MM-YYYY"},
+                               InputTestCase{"expiration date yyyy"},
+                               InputTestCase{"Exp Date     (MM / YYYY)"}));
 
   class ExpirationDate4DigitYearNegative
       : public testing::TestWithParam<InputTestCase> {};
@@ -199,7 +199,7 @@
     EXPECT_FALSE(MatchesPattern(ASCIIToUTF16(test_case.input), pattern));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillRegexes,
     ExpirationDate4DigitYearNegative,
     testing::Values(InputTestCase{""},
diff --git a/components/autofill/core/common/autofill_util_unittest.cc b/components/autofill/core/common/autofill_util_unittest.cc
index 6a59b0d..e240c5c 100644
--- a/components/autofill/core/common/autofill_util_unittest.cc
+++ b/components/autofill/core/common/autofill_util_unittest.cc
@@ -49,7 +49,7 @@
                 test_case.case_sensitive));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillUtilTest,
     FieldIsTokenBoundarySubstringCaseTest,
     testing::Values(
@@ -91,7 +91,7 @@
                 base::ASCIIToUTF16(test_case.field_contents)));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillUtilTest,
     PrefixEndingOnTokenBoundaryTest,
     testing::Values(AtSignPrefixCase{"ab@cd.b", "a", false},
@@ -136,7 +136,7 @@
                             test_case.case_sensitive));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillUtilTest,
     GetTextSelectionStartTest,
     testing::Values(
@@ -172,7 +172,7 @@
             LowercaseAndTokenizeAttributeString(test_case.attribute));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AutofillUtilTest,
     LowercaseAndTokenizeAttributeStringTest,
     testing::Values(
diff --git a/components/autofill/core/browser/credit_card_save_manager_unittest.cc b/components/autofill/core/browser/credit_card_save_manager_unittest.cc
index 765d6a3..bf633fb 100644
--- a/components/autofill/core/browser/credit_card_save_manager_unittest.cc
+++ b/components/autofill/core/browser/credit_card_save_manager_unittest.cc
@@ -2830,7 +2830,7 @@
 }
 
 // This class is parametrized to allow running all the inheriting tests with and
 // without a specific feature enabled. See INSTANTIATE_TEST_CASE_P.
 class CreditCardSaveManagerFeatureParameterizedTest
     : public CreditCardSaveManagerTest,
       public ::testing::WithParamInterface<
@@ -3927,9 +3927,9 @@
 //    Feature disabled
 //  CreditCardSaveManagerFeatureParameterizedTest.NothingIfNothingFound/1:
 //    Feature enabled.
-INSTANTIATE_TEST_CASE_P(,  // Empty instatiation name.
-                        CreditCardSaveManagerFeatureParameterizedTest,
-                        ::testing::Values(false, true));
+INSTANTIATE_TEST_SUITE_P(,  // Empty instatiation name.
+                         CreditCardSaveManagerFeatureParameterizedTest,
+                         ::testing::Values(false, true));
 
 TEST_F(CreditCardSaveManagerTest,
        UploadCreditCard_DoNotAddAnyFlagStatesToRequestIfExperimentsOff) {
@@ -2830,7 +2830,7 @@
 
 // This class is parametrized to allow running all the inheriting tests with and
-// without a specific feature enabled. See INSTANTIATE_TEST_CASE_P.
+// without a specific feature enabled. See INSTANTIATE_TEST_SUITE_P.
 class CreditCardSaveManagerFeatureParameterizedTest
     : public CreditCardSaveManagerTest,
diff --git a/components/autofill/core/browser/credit_card_unittest.cc b/components/autofill/core/browser/credit_card_unittest.cc
index 69d4e1b4..3a31bc4 100644
--- a/components/autofill/core/browser/credit_card_unittest.cc
+++ b/components/autofill/core/browser/credit_card_unittest.cc
@@ -364,19 +364,19 @@
       << test_case.expiration_year << " " << test_case.expected_year;
 }
 
-INSTANTIATE_TEST_CASE_P(CreditCardTest,
-                        SetExpirationYearFromStringTest,
-                        testing::Values(
-                            // Valid values.
-                            SetExpirationYearFromStringTestCase{"2040", 2040},
-                            SetExpirationYearFromStringTestCase{"45", 2045},
-                            SetExpirationYearFromStringTestCase{"045", 2045},
-                            SetExpirationYearFromStringTestCase{"9", 2009},
+INSTANTIATE_TEST_SUITE_P(CreditCardTest,
+                         SetExpirationYearFromStringTest,
+                         testing::Values(
+                             // Valid values.
+                             SetExpirationYearFromStringTestCase{"2040", 2040},
+                             SetExpirationYearFromStringTestCase{"45", 2045},
+                             SetExpirationYearFromStringTestCase{"045", 2045},
+                             SetExpirationYearFromStringTestCase{"9", 2009},
 
-                            // Unrecognized year values.
-                            SetExpirationYearFromStringTestCase{"052045", 0},
-                            SetExpirationYearFromStringTestCase{"123", 0},
-                            SetExpirationYearFromStringTestCase{"y2045", 0}));
+                             // Unrecognized year values.
+                             SetExpirationYearFromStringTestCase{"052045", 0},
+                             SetExpirationYearFromStringTestCase{"123", 0},
+                             SetExpirationYearFromStringTestCase{"y2045", 0}));
 
 struct SetExpirationDateFromStringTestCase {
   std::string expiration_date;
@@ -396,7 +396,7 @@
   EXPECT_EQ(test_case.expected_year, card.expiration_year());
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     SetExpirationDateFromStringTest,
     testing::Values(
@@ -486,7 +486,7 @@
       << " when comparing cards " << a.Label() << " and " << b.Label();
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     IsLocalDuplicateOfServerCardTest,
     testing::Values(
@@ -1152,9 +1152,9 @@
     {"2021", "01", "2019", LOCAL_CARD, ServerFieldTypeSet()},
 };
 
-INSTANTIATE_TEST_CASE_P(CreditCardTest,
-                        CreditCardMatchingTypesTest,
-                        testing::ValuesIn(kCreditCardMatchingTypesTestCases));
+INSTANTIATE_TEST_SUITE_P(CreditCardTest,
+                         CreditCardMatchingTypesTest,
+                         testing::ValuesIn(kCreditCardMatchingTypesTestCases));
 
 struct GetCardNetworkTestCase {
   const char* card_number;
@@ -1162,7 +1162,7 @@
   bool is_valid;
 };
 
 // We are doing batches here because INSTANTIATE_TEST_CASE_P has a
 // 50 upper limit.
 class GetCardNetworkTestBatch1
     : public testing::TestWithParam<GetCardNetworkTestCase> {};
@@ -1175,7 +1175,7 @@
   EXPECT_EQ(test_case.is_valid, IsValidCreditCardNumber(card_number));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     GetCardNetworkTestBatch1,
     testing::Values(
@@ -1238,7 +1238,7 @@
   EXPECT_EQ(test_case.is_valid, IsValidCreditCardNumber(card_number));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     GetCardNetworkTestBatch2,
     testing::Values(
@@ -1291,7 +1291,7 @@
   EXPECT_EQ(test_case.is_valid, IsValidCreditCardNumber(card_number));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     GetCardNetworkTestBatch3,
     testing::Values(
@@ -1351,7 +1351,7 @@
   EXPECT_EQ(test_case.is_valid, IsValidCreditCardNumber(card_number));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     GetCardNetworkTestBatch4,
     testing::Values(
@@ -1482,7 +1482,7 @@
             card.ShouldUpdateExpiration(testingTimes.now_));
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     CreditCardTest,
     ShouldUpdateExpirationTest,
     testing::Values(
@@ -1162,7 +1162,7 @@
 };
 
-// We are doing batches here because INSTANTIATE_TEST_CASE_P has a
+// We are doing batches here because INSTANTIATE_TEST_SUITE_P has a
 // 50 upper limit.
 class GetCardNetworkTestBatch1